==> ompl-0.14.0-Source.tar.gz: ompl-0.14.0-Source/doc/markdown/developers.md <==
# Developers

OMPL is developed and maintained by the [Physical and Biological Computing Group](http://www.kavrakilab.org) at Rice University, led by [Dr. Lydia Kavraki](http://www.cs.rice.edu/~kavraki). The development is coordinated by [Dr. Mark Moll](http://www.cs.rice.edu/~mmoll), [Dr. Lydia Kavraki](http://www.cs.rice.edu/~kavraki) (Rice) and [Dr. Ioan Șucan](http://ioan.sucan.ro) (Google\[X\], formerly Rice). Many others have contributed to OMPL as well, as can be seen below.

# Core developers:

- [Mark Moll](http://www.cs.rice.edu/~mmoll), Rice University
- [Ioan Șucan](http://ioan.sucan.ro), Google\[X\] (formerly Rice University)
- [Ryan Luna](http://www.ryanluna.com), Rice University
- [Luis Torres](http://luis.web.unc.edu), Ron Alterovitz' [Computational Robotics Group](http://robotics.cs.unc.edu), University of North Carolina at Chapel Hill


# Contributors:

- [Matt Maly](http://kavrakilab.org/profiles/mmaly), Rice University (now at Google)
- [Oren Salzman](http://acg.cs.tau.ac.il/people/oren-salzman/oren-salzman), Dan Halperin's [Computational Geometry Lab](http://acg.cs.tau.ac.il), Tel Aviv University
- [Dave Coleman](http://davetcoleman.com/),  Nikolaus Correll's [group](http://correll.cs.colorado.edu/), University of Colorado Boulder
- [Andrew Dobson](http://www.pracsyslab.org/dobson), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.pracsyslab.org), Rutgers University
- [James Marble](http://www.cse.unr.edu/robotics/pracsys/marble), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.cse.unr.edu/robotics/pracsys), University of Nevada, Reno
- Bryant Gipson, Rice University (now at Google)
- [Alejandro Perez](http://people.csail.mit.edu/aperez/www), Seth Teller's [Robotics, Vision, and Sensor Networks Group](http://rvsn.csail.mit.edu), MIT
- [Sertac Karaman](http://sertac.scripts.mit.edu/web), Emilio Frazzoli's [Aerospace Robotics and Embedded Systems Laboratory](http://ares.lids.mit.edu), MIT
- [Jennifer Barry](http://people.csail.mit.edu/jbarry), Leslie Pack Kaelbling and Tomás Lozano-Pérez's [Learning in Intelligent Systems Group](http://lis.csail.mit.edu), MIT (now)
- Elizabeth Fudge, Rice University
- Jonathan Sobieski, Rice University
- Beck Chen, Rice University
- [Sachin Chitta](http://www.willowgarage.com/pages/people/sachin-chitta-research-scientist), Willow Garage
- Gil Jones, Willow Garage

Click [here](thirdparty.html) for a detailed description of the third-party contributions.

==> ompl-1.1.0-Source.tar.gz: ompl-1.1.0-Source/doc/markdown/developers.md <==
# Developers

OMPL is developed and maintained by the [Physical and Biological Computing Group](http://www.kavrakilab.org) at Rice University, led by [Dr. Lydia Kavraki](http://www.cs.rice.edu/~kavraki). The development is coordinated by [Dr. Mark Moll](http://www.cs.rice.edu/~mmoll), [Dr. Lydia Kavraki](http://www.cs.rice.edu/~kavraki) (Rice) and [Dr. Ioan Șucan](http://ioan.sucan.ro) (Google\[X\], formerly Rice). Many others have contributed to OMPL as well, as can be seen below.

# Core developers:

- [Mark Moll](http://www.cs.rice.edu/~mmoll), Rice University
- [Ioan Șucan](http://ioan.sucan.ro), Google\[X\] (formerly Rice University)
- [Ryan Luna](http://www.ryanluna.com), Rice University
- [Luis Torres](http://luis.web.unc.edu), Ron Alterovitz' [Computational Robotics Group](http://robotics.cs.unc.edu), University of North Carolina at Chapel Hill


# Contributors:

- [Jonathan Gammell](http://asrl.utias.utoronto.ca/~jdg), Tim Barfoot's [Autonomous Space Robotics Lab](http://asrl.utias.utoronto.ca), University of Toronto
- [Prudvhi Boyapalli](http://www.boyapalli.org), Rice University
- Stephen Butler, Rice University
- Sonny Tarbouriech, University of Sherbrooke
- [Javier V Gomez](http://www.javiervgomez.com), Universidad Carlos III de Madrid
- [Ashley Clark](http://web.stanford.edu/group/arl/people/ashley-clark), Steve Rock's [Aerospace Robotics Lab](http://web.stanford.edu/group/arl), Stanford University
- Edward Schmerling, Marco Pavone's [Autonomous Systems Lab](http://asl.stanford.edu), Stanford University
- Caleb Voss, Rice University
- Matt Maly, Rice University (now at Google)
- [Oren Salzman](http://acg.cs.tau.ac.il/people/oren-salzman/oren-salzman), Dan Halperin's [Computational Geometry Lab](http://acg.cs.tau.ac.il), Tel Aviv University
- [Dave Coleman](http://davetcoleman.com/),  Nikolaus Correll's [group](http://correll.cs.colorado.edu/), University of Colorado Boulder
- [Andrew Dobson](http://www.pracsyslab.org/dobson), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.pracsyslab.org), Rutgers University
- [James Marble](http://www.cse.unr.edu/robotics/pracsys/marble), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.cse.unr.edu/robotics/pracsys), University of Nevada, Reno
- Bryant Gipson, Rice University (now at Google)
- [Alejandro Perez](http://people.csail.mit.edu/aperez/www), Seth Teller's [Robotics, Vision, and Sensor Networks Group](http://rvsn.csail.mit.edu), MIT
- [Sertac Karaman](http://sertac.scripts.mit.edu/web), Emilio Frazzoli's [Aerospace Robotics and Embedded Systems Laboratory](http://ares.lids.mit.edu), MIT
- [Jennifer Barry](http://people.csail.mit.edu/jbarry), Leslie Pack Kaelbling and Tomás Lozano-Pérez's [Learning in Intelligent Systems Group](http://lis.csail.mit.edu), MIT (now at Rethink Robotics)
- Elizabeth Fudge, Rice University
- Jonathan Sobieski, Rice University
- Beck Chen, Rice University
- [Sachin Chitta](http://www.sachinchitta.org), SRI International
- Gil Jones, Google

Click [here](thirdparty.html) for a detailed description of some of the third-party contributions.
